@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::Mercurial;
-BEGIN {
-  $Dist::Zilla::Plugin::Mercurial::VERSION = '0.03';
+{
+  $Dist::Zilla::Plugin::Mercurial::VERSION = '0.05';
 }
 
 use strict;
@@ -10,7 +10,7 @@ use warnings;
 
 # ABSTRACT: A Mercurial plugin for Dist::Zilla
 
-
+__END__
 
 =pod
 
@@ -20,7 +20,7 @@ Dist::Zilla::Plugin::Mercurial - A Mercurial plugin for Dist::Zilla
 
 =head1 VERSION
 
-version 0.03
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -65,7 +65,7 @@ button on this page: L<http://www.urth.org/~autarch/fs-donation.html>
 
 =head1 AUTHOR
 
-  Dave Rolsky <autarch@urth.org>
+Shlomi Fish <shlomif@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -75,7 +75,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
